<?php


module_load_include ( 'inc', 'icl_core', 'icl_core.constants' );
module_load_include ( 'inc', 'icl_core', 'icl_core.settings' );


function icl_status_check() {
  include_once 'includes/install.inc';

  $requirements = array();
  
  // check translation languages.
  $icl_core_languages = variable_get('icl_core_languages', array());
  $icl_core_languages = variable_get('icl_core_languages', array());
  
  foreach($icl_core_languages['have_translators'] as $from_lang => $to_langs) {
    $from_lang = icl_core_get_drupal_language_name_from_ican_language($from_lang);
    foreach($to_langs as $to_lang => $available) {
      $to_lang = icl_core_get_drupal_language_name_from_ican_language($to_lang);
      if ($available) {
        $requirements['icl_languages_'.$from_lang.'_'.$to_lang] = array(
                                              'title' => t('Languages'),
                                              'value' => t('Translators available for @from to @to', array('@from' => $from_lang, '@to' => $to_lang)),
                                              'severity' => REQUIREMENT_OK,
                                              );
      } else {
        $requirements['icl_languages_'.$from_lang.'_'.$to_lang] = array(
                                              'title' => t('Languages'),
                                              'value' => t('No translators assigned yet for @from to @to', array('@from' => $from_lang, '@to' => $to_lang)),
                                              'severity' => REQUIREMENT_WARNING,
                                              );
      }
    }
  }
  
  $query = db_query("SELECT * FROM {node_type} WHERE 1");
  while($result = db_fetch_object($query)) {

    $enabled = variable_get('language_content_type_'. $result->type, 0);
    if ($enabled == 2) {
      $requirements['language_content_type_'. $result->type] = array(
                                          'title' => $result->name,
                                          'value' => t('Content type @type has multilingual support enabled', array('@type' => $result->name)),
                                          'severity' => REQUIREMENT_OK,
                                          );
    } else {
      $link = '/admin/content/node-type/'.$result->type;
      $requirements['language_content_type_'. $result->type] = array(
                                          'title' => $result->name,
                                          'value' => t('Multilingual support is not enabled for content type @type', array('@type' => $result->name)),
                                          'description' => t('To enable multilingual support, go to <a href="@link">@type edit</a> and enable it in the Workflow settings', array('@link' => $link, '@type' => $result->type)),
                                          'severity' => REQUIREMENT_WARNING,
                                          );
      
    }
    
  }
  
  
  if (module_exists ( 'i18ntaxonomy' )) {
    $requirements['i18ntaxonomy'] = array(
                                          'title' => 'i18n Taxonomy',
                                          'value' => 'i18ntaxonomy module enabled',
                                          'severity' => REQUIREMENT_OK,
                                          );
  } else {
    $requirements['i18ntaxonomy'] = array(
                                          'title' => 'i18n Taxonomy',
                                          'value' => 'i18ntaxonomy module is not enabled',
                                          'description' => 'Enable the i18ntaxonomy module if you want to have taxonomy translated.',
                                          'severity' => REQUIREMENT_WARNING,
                                          );
  }

  if (module_exists ( 'i18nblocks' )) {
    $requirements['i18nblocks'] = array(
                                          'title' => 'i18n Blocks',
                                          'value' => 'i18nblocks module enabled',
                                          'severity' => REQUIREMENT_OK,
                                          );
  } else {
    $requirements['i18nblocks'] = array(
                                          'title' => 'i18n Blocks',
                                          'value' => 'i18nblocks module is not enabled',
                                          'description' => 'Enable the i18nblocks module if you want to have taxonomy translated.',
                                          'severity' => REQUIREMENT_WARNING,
                                          );
  }

  return theme('status_report', $requirements);

}